============
Installation
============

At the command line::

    $ easy_install python-msspeak

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv python-msspeak
    $ pip install python-msspeak
